Struct NoCustomError
pub struct NoCustomError;๐Deprecated since 0.8.0: Now server_fn can return any error type other than ServerFnError, so the WrappedServerError variant will be removed in 0.9.0
An empty value indicating that there is no custom error type associated with this server function.